"""
Django settings for auth_prj project.

Generated by 'django-admin startproject' using Django 4.2.14.

For more information on this file, see
https://docs.djangoproject.com/en/4.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.2/ref/settings/
"""
import os
from dotenv import load_dotenv
from pathlib import Path
from datetime import timedelta
import sys

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

# 우선순위: .env.dev > .env.prd > .env
if os.path.exists(os.path.join(BASE_DIR, '.env.dev')):
    # print("Read Environment File > Used : .env.dev")
    load_dotenv(os.path.join(BASE_DIR, '.env.dev'))
elif os.path.exists(os.path.join(BASE_DIR, '.env.prd')):
    # print("Read Environment File > Used : .env.prd")
    load_dotenv(os.path.join(BASE_DIR, '.env.prd'))
else:
    pass
    # print("None Environment File > Used : local_env")
    
# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ.get('SECRET_KEY', 'django-insecure-ec9me^z%x7-2vwee5#qq(kvn@^cs!!22_*f-im(320_k5-=0j5')

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = int(os.environ.get('DEBUG', 1))

LOG_LEVEL = "DEBUG" if DEBUG else "INFO"

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,  # Django 기본 로거 유지
    'formatters': {
        'standard': {
            'format': '[{asctime}] {levelname} {name}:{lineno} {message}',
            'style': '{',
        },
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',  # 콘솔 출력
            'formatter': 'standard',
            'stream': sys.stdout,  # 표준 출력 스트림
            'level': LOG_LEVEL,  # 콘솔 출력 레벨 설정
            # 'filters': [],  # 필터 설정 (필요시 추가)
            # 'encoding': 'utf-8',  # UTF-8 인코딩 설정
            # 'force': True,  # 강제로 콘솔 출력
        },
    },
    'root': {
        'handlers': ['console'],
        'level': LOG_LEVEL,  # 루트 로거 레벨 설정
    },
    'loggers': {
        'django': {
            'handlers': ['console'],
            'level': 'INFO',    # Django 프레임워크 전반
            'propagate': False,
        },
        'django.request': {
            'handlers': ['console'],
            'level': 'ERROR',   # 요청 관련 에러만 (500 에러 같은 것)
            'propagate': False,
        },
        'django.db.backends': {
            'handlers': ['console'],
            'level': 'WARNING',  # DB 쿼리 경고만
            'propagate': False,
        },
        'django.security': {
            'handlers': ['console'],
            'level': 'WARNING',  # 보안 관련 경고
            'propagate': False,
        },
    },
}

# AUTH_VERIFY_URL = os.environ.get('AUTH_VERIFY_URL', 'NONE')

ALLOWED_HOSTS = ["*"]

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # by.sdjo
    'rest_framework',
    'rest_framework_simplejwt',
    'rest_framework_simplejwt.token_blacklist',
    'drf_yasg',
    'corsheaders',
    # create by.sdjo 2025-04-22
    'users', # 2025-04-22 custom app create
    
]

AUTH_USER_MODEL = 'users.CustomUser'

MIDDLEWARE = [
    'corsheaders.middleware.CorsMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

# by.sdjo 2025-04-22
CORS_ALLOWED_ORIGINS = [
    "http://localhost:3000",
    "http://127.0.0.1:3000",
    "http://192.168.0.100:3000",
    "https://demo.test",
    "http://demo.test",
    "https://www.demo.test",
    "https://sample.test",
    "http://sample.test",
    "http://www.sample.test",
    "http://auth.sample.test",
    "http://blog.sample.test",
    "https://www.icurfer.com",
    "https://icurfer.com",
]

# by.sdjo 2025-04-22
REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'rest_framework_simplejwt.authentication.JWTAuthentication',
    )
}

ROOT_URLCONF = 'auth_prj.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'auth_prj.wsgi.application'

SIMPLE_JWT = {
    "ACCESS_TOKEN_LIFETIME": timedelta(minutes=5),
    "REFRESH_TOKEN_LIFETIME": timedelta(days=1),
    "ROTATE_REFRESH_TOKENS": True,
    "BLACKLIST_AFTER_ROTATION": True, # 사용한 토큰은 갱신하면 블랙리스트처리됨
}

DATABASES = {
    "default": {
        'ENGINE': os.environ.get('SQL_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': os.environ.get('SQL_DATABASE', BASE_DIR / 'db.sqlite3'),
        'USER': os.environ.get('SQL_USER', 'user'),
        'PASSWORD': os.environ.get('SQL_PASSWORD', 'password'),
        'HOST': os.environ.get('SQL_HOST', 'localhost'),
        'PORT': os.environ.get('SQL_PORT', '3306'),
    }
}


# Password validation
# https://docs.djangoproject.com/en/4.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/4.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.2/howto/static-files/

STATIC_URL = 'static/'

# Default primary key field type
# https://docs.djangoproject.com/en/4.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
