from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from .models import CustomUser
from rest_framework_simplejwt.tokens import RefreshToken


class CustomUserAdmin(UserAdmin):
    model = CustomUser
    list_display = (
        'email', 'name', 'grade', 'desc',
        'is_active', 'is_staff', 'jwt_preview',
        'encrypted_private_key_name'  # ✅ 키 이름 컬럼 추가
    )
    list_filter = ('grade', 'is_active', 'is_staff')
    search_fields = ('email', 'name')
    ordering = ('email',)

    readonly_fields = (
        'created_at', 'last_login', 'jwt_preview',
        'encrypted_private_key_name',  # ✅ 키 이름 읽기 전용
        'encrypted_private_key_preview'
        
    )

    fieldsets = (
        (None, {'fields': ('email', 'password')}),
        ('Personal Info', {'fields': ('name', 'grade', 'desc')}),
        ('Permissions', {'fields': (
            'is_active', 'is_staff', 'is_superuser',
            'groups', 'user_permissions'
        )}),
        ('Important dates', {'fields': ('last_login',)}),
        ('JWT Token Preview', {'fields': ('jwt_preview',)}),
        ('SSH Key Info', {  # ✅ 키 정보 그룹
            'fields': (
                'encrypted_private_key_name',
                'encrypted_private_key_preview'
            )
        }),
    )

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': (
                'email', 'name', 'grade', 'desc',
                'password1', 'password2',
                'is_active', 'is_staff', 'is_superuser'
            ),
        }),
    )

    def jwt_preview(self, obj):
        try:
            refresh = RefreshToken.for_user(obj)
            access_token = str(refresh.access_token)
            return access_token[:30] + "..."
        except Exception:
            return "N/A"
    jwt_preview.short_description = "JWT Access Preview"

    def encrypted_private_key_preview(self, obj):
        if obj.encrypted_private_key:
            return str(obj.encrypted_private_key)[:30] + "..."
        return "없음"
    encrypted_private_key_preview.short_description = "SSH Key (암호화)"


admin.site.register(CustomUser, CustomUserAdmin)
